@@ -55,8 +55,10 @@ var AccountsMonitor = class {
             return settings;
 
         let path = `/org/gnome/Polari/Accounts/${account.get_path_suffix()}/`;
-        settings = new Gio.Settings({ schema_id: 'org.gnome.Polari.Account',
-                                      path: path });
+        settings = new Gio.Settings({
+            schema_id: 'org.gnome.Polari.Account',
+            path: path
+        });
         this._accountSettings.set(accountPath, settings);
         return settings;
     }
@@ -91,7 +93,7 @@ var AccountsMonitor = class {
         am.connect('account-enabled', this._accountEnabledChanged.bind(this));
         am.connect('account-disabled', this._accountEnabledChanged.bind(this));
 
-        this._preparedCallbacks.forEach(callback => { callback(); });
+        this._preparedCallbacks.forEach(callback => callback());
     }
 
     _onPrepareShutdown() {
@@ -124,8 +126,9 @@ var AccountsMonitor = class {
             });
         account._visibleNotifyId =
             account.connect('notify::visible', () => {
-                this.emit(account.visible ? 'account-shown'
-                                          : 'account-hidden', account);
+                let signal = account.visible ?
+                    'account-shown' : 'account-hidden';
+                this.emit(signal, account);
                 this.emit('accounts-changed');
             });
         this._accounts.set(account.object_path, account);
@@ -151,8 +154,8 @@ var AccountsMonitor = class {
     _accountEnabledChanged(am, account) {
         if (!this._accounts.has(account.object_path))
             return;
-        this.emit(account.enabled ? 'account-enabled'
-                                  : 'account-disabled', account);
+        let signal = account.enabled ? 'account-enabled' : 'account-disabled';
+        this.emit(signal, account);
         this.emit('accounts-changed');
     }
 };
@@ -161,10 +164,12 @@ Signals.addSignalMethods(AccountsMonitor.prototype);
 const ClientFactory = GObject.registerClass(
 class ClientFactory extends Polari.ClientFactory {
     vfunc_create_account(objectPath) {
-        return new PolariAccount({ factory: this,
-                                   dbus_daemon: this.dbus_daemon,
-                                   bus_name: Tp.ACCOUNT_MANAGER_BUS_NAME,
-                                   object_path: objectPath });
+        return new PolariAccount({
+            factory: this,
+            dbus_daemon: this.dbus_daemon,
+            bus_name: Tp.ACCOUNT_MANAGER_BUS_NAME,
+            object_path: objectPath
+        });
     }
 });
 
