@@ -20,12 +20,16 @@ const MAX_RETRIES = 3;
 const IRC_SCHEMA_REGEX = /^(irc?:\/\/)([\da-z.-]+):?(\d+)?\/(?:%23)?([\w.+-]+)/i;
 
 var Application = GObject.registerClass({
-    Signals: { 'prepare-shutdown': {},
-               'room-focus-changed': {} },
+    Signals: {
+        'prepare-shutdown': {},
+        'room-focus-changed': {}
+    }
 }, class Application extends Gtk.Application {
     _init() {
-        super._init({ application_id: 'org.gnome.Polari',
-                      flags: Gio.ApplicationFlags.HANDLES_OPEN });
+        super._init({
+            application_id: 'org.gnome.Polari',
+            flags: Gio.ApplicationFlags.HANDLES_OPEN
+        });
 
         GLib.set_prgname('polari');
         this._retryData = new Map();
@@ -36,18 +40,18 @@ var Application = GObject.registerClass({
 
         this.add_main_option('start-client', 0,
                              GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-                             _("Start Telepathy client"), null);
+                             _('Start Telepathy client'), null);
         // Only included for --help output, the actual option is handled
         // from C before handling over control to JS
         this.add_main_option('debugger', 'd',
                              GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-                             _("Start in debug mode"), null);
+                             _('Start in debug mode'), null);
         this.add_main_option('test-instance', 0,
                              GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-                             _("Allow running alongside another instance"), null);
+                             _('Allow running alongside another instance'), null);
         this.add_main_option('version', 0,
                              GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
-                             _("Print version and exit"), null);
+                             _('Print version and exit'), null);
         this.connect('handle-local-options', (o, dict) => {
             let v = dict.lookup_value('test-instance', null);
             if (v && v.get_boolean())
@@ -174,77 +178,100 @@ var Application = GObject.registerClass({
     vfunc_startup() {
         super.vfunc_startup();
 
-        /* eslint-disable indent */
-        let actionEntries = [
-          { name: 'show-join-dialog',
+        let actionEntries = [{
+            name: 'show-join-dialog',
             activate: this._onShowJoinDialog.bind(this),
-            accels: ['<Primary>n'] },
-          { name: 'join-room',
+            accels: ['<Primary>n']
+        }, {
+            name: 'join-room',
             activate: this._onJoinRoom.bind(this),
-            parameter_type: GLib.VariantType.new('(ssu)') },
-          { name: 'message-user',
+            parameter_type: GLib.VariantType.new('(ssu)')
+        }, {
+            name: 'message-user',
             activate: this._onMessageUser.bind(this),
-            parameter_type: GLib.VariantType.new('(sssu)') },
-          { name: 'leave-room',
-            parameter_type: GLib.VariantType.new('(ss)') },
-          { name: 'leave-current-room',
+            parameter_type: GLib.VariantType.new('(sssu)')
+        }, {
+            name: 'leave-room',
+            parameter_type: GLib.VariantType.new('(ss)')
+        }, {
+            name: 'leave-current-room',
             activate: this._onLeaveCurrentRoom.bind(this),
-            create_hook: (a) => { a.enabled = false; },
-            accels: ['<Primary>w'] },
-          { name: 'authenticate-account',
-            parameter_type: GLib.VariantType.new('(os)') },
-          { name: 'connect-account',
+            create_hook: (a) => a.enabled = false,
+            accels: ['<Primary>w']
+        }, {
+            name: 'authenticate-account',
+            parameter_type: GLib.VariantType.new('(os)')
+        }, {
+            name: 'connect-account',
             activate: this._onConnectAccount.bind(this),
-            parameter_type: GLib.VariantType.new('o') },
-          { name: 'disconnect-account',
+            parameter_type: GLib.VariantType.new('o')
+        }, {
+            name: 'disconnect-account',
             activate: this._onConnectAccount.bind(this),
-            parameter_type: GLib.VariantType.new('o') },
-          { name: 'reconnect-account',
+            parameter_type: GLib.VariantType.new('o')
+        }, {
+            name: 'reconnect-account',
             activate: this._onConnectAccount.bind(this),
-            parameter_type: GLib.VariantType.new('o') },
-          { name: 'user-list',
+            parameter_type: GLib.VariantType.new('o')
+        }, {
+            name: 'user-list',
             activate: this._onToggleAction.bind(this),
             create_hook: this._userListCreateHook.bind(this),
             state: GLib.Variant.new('b', false),
-            accels: ['F9', '<Primary>u'] },
-          { name: 'remove-connection',
+            accels: ['F9', '<Primary>u']
+        }, {
+            name: 'remove-connection',
             activate: this._onRemoveConnection.bind(this),
-            parameter_type: GLib.VariantType.new('o') },
-          { name: 'edit-connection',
+            parameter_type: GLib.VariantType.new('o')
+        }, {
+            name: 'edit-connection',
             activate: this._onEditConnection.bind(this),
-            parameter_type: GLib.VariantType.new('o') },
-          { name: 'save-identify-password',
-            parameter_type: GLib.VariantType.new('o') },
-          { name: 'discard-identify-password',
-            parameter_type: GLib.VariantType.new('o') },
-          { name: 'show-emoji-picker',
-            accels: ['<Primary>e'] },
-          { name: 'start-client',
-            activate: this._onStartClient.bind(this) },
-          { name: 'help',
+            parameter_type: GLib.VariantType.new('o')
+        }, {
+            name: 'save-identify-password',
+            parameter_type: GLib.VariantType.new('o')
+        }, {
+            name: 'discard-identify-password',
+            parameter_type: GLib.VariantType.new('o')
+        }, {
+            name: 'show-emoji-picker',
+            accels: ['<Primary>e']
+        }, {
+            name: 'start-client',
+            activate: this._onStartClient.bind(this)
+        }, {
+            name: 'help',
             activate: this._onShowHelp.bind(this),
-            accels: ['F1'] },
-          { name: 'about',
-            activate: this._onShowAbout.bind(this) },
-          { name: 'quit',
+            accels: ['F1']
+        }, {
+            name: 'about',
+            activate: this._onShowAbout.bind(this)
+        }, {
+            name: 'quit',
             activate: this._onQuit.bind(this),
-            accels: ['<Primary>q'] },
-          { name: 'next-room',
-            accels: ['<Primary>Page_Down', '<Alt>Down'] },
-          { name: 'previous-room',
-            accels: ['<Primary>Page_Up', '<Alt>Up'] },
-          { name: 'first-room',
-            accels: ['<Primary>Home'] },
-          { name: 'last-room',
-            accels: ['<Primary>End'] },
-          { name: 'nth-room',
-            parameter_type: GLib.VariantType.new('i') },
-          { name: 'next-pending-room',
-            accels: ['<Alt><Shift>Down', '<Primary><Shift>Page_Down'] },
-          { name: 'previous-pending-room',
-            accels: ['<Alt><Shift>Up', '<Primary><Shift>Page_Up'] }
-        ];
-        /* eslint-enable indent */
+            accels: ['<Primary>q']
+        }, {
+            name: 'next-room',
+            accels: ['<Primary>Page_Down', '<Alt>Down']
+        }, {
+            name: 'previous-room',
+            accels: ['<Primary>Page_Up', '<Alt>Up']
+        }, {
+            name: 'first-room',
+            accels: ['<Primary>Home']
+        }, {
+            name: 'last-room',
+            accels: ['<Primary>End']
+        }, {
+            name: 'nth-room',
+            parameter_type: GLib.VariantType.new('i')
+        }, {
+            name: 'next-pending-room',
+            accels: ['<Alt><Shift>Down', '<Primary><Shift>Page_Down']
+        }, {
+            name: 'previous-pending-room',
+            accels: ['<Alt><Shift>Up', '<Primary><Shift>Page_Up']
+        }];
         actionEntries.forEach(actionEntry => {
             let props = {};
             ['name', 'state', 'parameter_type'].forEach(prop => {
@@ -351,9 +378,9 @@ var Application = GObject.registerClass({
                     this.emit('prepare-shutdown');
                 });
                 window.connect('notify::active-room',
-                               () => { this.emit('room-focus-changed'); });
+                               () => this.emit('room-focus-changed'));
                 window.connect('notify::is-active',
-                               () => { this.emit('room-focus-changed'); });
+                               () => this.emit('room-focus-changed'));
             }
         }
 
@@ -417,9 +444,10 @@ var Application = GObject.registerClass({
             else
                 this._createAccount(matchedId, server, port, a => {
                     if (a)
-                        joinAction.activate(new GLib.Variant('(ssu)',
-                                                             [a.get_object_path(),
-                                                              `#${room}`, time]));
+                        joinAction.activate(new GLib.Variant('(ssu)', [
+                            a.get_object_path(),
+                            `#${room}`, time
+                        ]));
                 });
         });
     }
@@ -431,7 +459,7 @@ var Application = GObject.registerClass({
             [,, server, port, room] = uri.match(IRC_SCHEMA_REGEX);
             success = true;
         } catch (e) {
-            let label = _("Failed to open link");
+            let label = _('Failed to open link');
             let n = new AppNotifications.MessageNotification(label,
                                                              'dialog-error-symbolic');
             this.notificationQueue.addNotification(n);
@@ -456,10 +484,12 @@ var Application = GObject.registerClass({
             name = server;
         }
 
-        let req = new Tp.AccountRequest({ account_manager: Tp.AccountManager.dup(),
-                                          connection_manager: 'idle',
-                                          protocol: 'irc',
-                                          display_name: name });
+        let req = new Tp.AccountRequest({
+            account_manager: Tp.AccountManager.dup(),
+            connection_manager: 'idle',
+            protocol: 'irc',
+            display_name: name
+        });
         req.set_enabled(true);
 
         if (id)
@@ -649,9 +679,11 @@ var Application = GObject.registerClass({
             return false;
 
         debug(`Retrying with ${server.address}:${server.port}`);
-        let params = { server: new GLib.Variant('s', server.address),
-                       port: new GLib.Variant('u', server.port),
-                       'use-ssl': new GLib.Variant('b', server.ssl) };
+        let params = {
+            server: new GLib.Variant('s', server.address),
+            port: new GLib.Variant('u', server.port),
+            'use-ssl': new GLib.Variant('b', server.ssl)
+        };
         this._retryWithParams(account, new GLib.Variant('a{sv}', params));
         return true;
     }
@@ -718,7 +750,7 @@ var Application = GObject.registerClass({
             account.set_enabled_finish(res);
             account.visible = false;
 
-            let label = _("%s removed.").format(account.display_name);
+            let label = _('%s removed.').format(account.display_name);
             let n = new AppNotifications.UndoNotification(label);
             this.notificationQueue.addNotification(n);
 
@@ -793,13 +825,13 @@ var Application = GObject.registerClass({
                 'Lapo Calamandrei <calamandrei@gmail.com>',
                 'Tobias Bernard <tbernard@gnome.org>'
             ],
-            translator_credits: _("translator-credits"),
-            comments: _("An Internet Relay Chat Client for GNOME"),
+            translator_credits: _('translator-credits'),
+            comments: _('An Internet Relay Chat Client for GNOME'),
             copyright: 'Copyright © 2013-2018 The Polari authors',
             license_type: Gtk.License.GPL_2_0,
             logo_icon_name: 'org.gnome.Polari',
             version: pkg.version,
-            website_label: _("Learn more about Polari"),
+            website_label: _('Learn more about Polari'),
             website: 'https://wiki.gnome.org/Apps/Polari',
 
             transient_for: this.active_window,
@@ -819,7 +851,7 @@ var Application = GObject.registerClass({
             this.disconnect(this._windowRemovedId);
         this._windowRemovedId = 0;
 
-        this.get_windows().reverse().forEach(w => { w.destroy(); });
+        this.get_windows().reverse().forEach(w => w.destroy());
         this.emit('prepare-shutdown');
     }
 });
