@@ -4,7 +4,6 @@ const {
     Gdk, Gio, GLib, GObject, Gtk, Pango, PangoCairo, Polari,
     TelepathyGLib: Tp, TelepathyLogger: Tpl
 } = imports.gi;
-const Mainloop = imports.mainloop;
 
 const { DropTargetIface } = imports.pasteManager;
 const { UserPopover } = imports.userList;
@@ -135,7 +134,7 @@ class TextView extends Gtk.TextView {
 
     _updateLayout() {
         this._layout = this.create_pango_layout(null);
-        this._layout.set_markup(`<small><b>${_("New Messages")}</b></small>`, -1);
+        this._layout.set_markup(`<small><b>${_('New Messages')}</b></small>`, -1);
     }
 });
 
@@ -148,9 +147,9 @@ const ButtonTag = GObject.registerClass({
                                            false)
     },
     Signals: {
-        'clicked': { },
-        'popup-menu': { }
-    },
+        'clicked': {},
+        'popup-menu': {}
+    }
 }, class ButtonTag extends Gtk.TextTag {
     _init(params) {
         this._hover = false;
@@ -186,9 +185,11 @@ const ButtonTag = GObject.registerClass({
         if (this._gesture)
             return;
 
-        this._gesture = new Gtk.GestureMultiPress({ widget,
-                                                    button: 0,
-                                                    exclusive: true });
+        this._gesture = new Gtk.GestureMultiPress({
+            widget,
+            button: 0,
+            exclusive: true
+        });
 
         this._gesture.connect('pressed', (gesture, nPress) => {
             if (!this._hover || nPress > 1)
@@ -230,7 +231,7 @@ const HoverFilterTag = GObject.registerClass({
 
         super._init(params);
 
-        this.connect('notify::hover', () => { this._updateColor(); });
+        this.connect('notify::hover', () => this._updateColor());
     }
 
     _updateColor() {
@@ -292,9 +293,11 @@ var ChatView = GObject.registerClass({
 
         this.get_style_context().add_class('polari-chat-view');
 
-        this._view = new TextView({ editable: false, cursor_visible: false,
-                                    wrap_mode: Gtk.WrapMode.WORD_CHAR,
-                                    right_margin: MARGIN });
+        this._view = new TextView({
+            editable: false, cursor_visible: false,
+            wrap_mode: Gtk.WrapMode.WORD_CHAR,
+            right_margin: MARGIN
+        });
         this._view.add_events(Gdk.EventMask.LEAVE_NOTIFY_MASK |
                               Gdk.EventMask.ENTER_NOTIFY_MASK);
         this.add(this._view);
@@ -351,9 +354,10 @@ var ChatView = GObject.registerClass({
         this._updateMaxNickChars(this._room.account.nickname.length);
 
         let isRoom = room.type == Tp.HandleType.ROOM;
-        let target = new Tpl.Entity({ type: isRoom ? Tpl.EntityType.ROOM
-                                                   : Tpl.EntityType.CONTACT,
-                                      identifier: room.channel_name });
+        let target = new Tpl.Entity({
+            type: isRoom ? Tpl.EntityType.ROOM : Tpl.EntityType.CONTACT,
+            identifier: room.channel_name
+        });
         let logManager = Tpl.LogManager.dup_singleton();
         this._logWalker =
             logManager.walk_filtered_events(room.account, target,
@@ -378,22 +382,28 @@ var ChatView = GObject.registerClass({
         this._channelSignals = [];
         this._channel = null;
 
-        let roomSignals = [
-            { name: 'notify::channel',
-              handler: this._onChannelChanged.bind(this) },
-            { name: 'member-renamed',
-              handler: this._onMemberRenamed.bind(this) },
-            { name: 'member-disconnected',
-              handler: this._onMemberDisconnected.bind(this) },
-            { name: 'member-kicked',
-              handler: this._onMemberKicked.bind(this) },
-            { name: 'member-banned',
-              handler: this._onMemberBanned.bind(this) },
-            { name: 'member-joined',
-              handler: this._onMemberJoined.bind(this) },
-            { name: 'member-left',
-              handler: this._onMemberLeft.bind(this) }
-        ];
+        let roomSignals = [{
+            name: 'notify::channel',
+            handler: this._onChannelChanged.bind(this)
+        }, {
+            name: 'member-renamed',
+            handler: this._onMemberRenamed.bind(this)
+        }, {
+            name: 'member-disconnected',
+            handler: this._onMemberDisconnected.bind(this)
+        }, {
+            name: 'member-kicked',
+            handler: this._onMemberKicked.bind(this)
+        }, {
+            name: 'member-banned',
+            handler: this._onMemberBanned.bind(this)
+        }, {
+            name: 'member-joined',
+            handler: this._onMemberJoined.bind(this)
+        }, {
+            name: 'member-left',
+            handler: this._onMemberLeft.bind(this)
+        }];
         this._roomSignals = [];
         roomSignals.forEach(signal => {
             this._roomSignals.push(room.connect(signal.name, signal.handler));
@@ -408,38 +418,45 @@ var ChatView = GObject.registerClass({
     _createTags() {
         let buffer = this._view.get_buffer();
         let tagTable = buffer.get_tag_table();
-        let tags = [
-            /* eslint-disable indent */
-          { name: 'nick',
+        let tags = [{
+            name: 'nick',
             left_margin: MARGIN,
-            weight: Pango.Weight.BOLD },
-          { name: 'gap',
-            pixels_above_lines: 10 },
-          { name: 'message',
-            indent: 0 },
-          { name: 'highlight',
-            weight: Pango.Weight.BOLD },
-          { name: 'status',
+            weight: Pango.Weight.BOLD
+        }, {
+            name: 'gap',
+            pixels_above_lines: 10
+        }, {
+            name: 'message',
+            indent: 0
+        }, {
+            name: 'highlight',
+            weight: Pango.Weight.BOLD
+        }, {
+            name: 'status',
             left_margin: MARGIN,
             indent: 0,
-            justification: Gtk.Justification.RIGHT },
-          { name: 'timestamp',
+            justification: Gtk.Justification.RIGHT
+        }, {
+            name: 'timestamp',
             left_margin: MARGIN,
             indent: 0,
-            justification: Gtk.Justification.RIGHT },
-          { name: 'action',
+            justification: Gtk.Justification.RIGHT
+        }, {
+            name: 'action',
             left_margin: MARGIN,
-            style: Pango.Style.ITALIC },
-          { name: 'url',
-            underline: Pango.Underline.SINGLE },
-          { name: 'indicator-line',
-            pixels_above_lines: 24 },
-          { name: 'loading',
+            style: Pango.Style.ITALIC
+        }, {
+            name: 'url',
+            underline: Pango.Underline.SINGLE
+        }, {
+            name: 'indicator-line',
+            pixels_above_lines: 24
+        }, {
+            name: 'loading',
             left_margin: MARGIN,
-            justification: Gtk.Justification.CENTER }
-            /* eslint-enable indent */
-        ];
-        tags.forEach(tagProps => { tagTable.add(new Gtk.TextTag(tagProps)); });
+            justification: Gtk.Justification.CENTER
+        }];
+        tags.forEach(tagProps => tagTable.add(new Gtk.TextTag(tagProps)));
     }
 
     _onStyleUpdated() {
@@ -462,10 +479,12 @@ var ChatView = GObject.registerClass({
         let desaturatedNickColor = (this._activeNickColor.red +
                                     this._activeNickColor.blue +
                                     this._activeNickColor.green) / 3;
-        this._inactiveNickColor = new Gdk.RGBA ({ red: desaturatedNickColor,
-                                                  green: desaturatedNickColor,
-                                                  blue: desaturatedNickColor,
-                                                  alpha: 1.0 });
+        this._inactiveNickColor = new Gdk.RGBA({
+            red: desaturatedNickColor,
+            green: desaturatedNickColor,
+            blue: desaturatedNickColor,
+            alpha: 1.0
+        });
         if (this._activeNickColor.equal(this._inactiveNickColor))
             this._inactiveNickColor.alpha = 0.5;
 
@@ -477,16 +496,16 @@ var ChatView = GObject.registerClass({
 
         let buffer = this._view.get_buffer();
         let tagTable = buffer.get_tag_table();
-        let tags = [
-            /* eslint-disable indent */
-          { name: 'status',
-            foreground_rgba: dimColor },
-          { name: 'timestamp',
-            foreground_rgba: dimColor },
-          { name: 'url',
-            foreground_rgba: linkColor }
-            /* eslint-enable indent */
-        ];
+        let tags = [{
+            name: 'status',
+            foreground_rgba: dimColor
+        }, {
+            name: 'timestamp',
+            foreground_rgba: dimColor
+        }, {
+            name: 'url',
+            foreground_rgba: linkColor
+        }];
         tags.forEach(tagProps => {
             let tag = tagTable.lookup(tagProps.name);
             for (let prop in tagProps) {
@@ -524,7 +543,7 @@ var ChatView = GObject.registerClass({
         this._roomFocusChangedId = 0;
 
         if (this._backlogTimeoutId)
-            Mainloop.source_remove(this._backlogTimeoutId);
+            GLib.source_remove(this._backlogTimeoutId);
         this._backlogTimeoutId = 0;
 
         if (this._nickStatusChangedId)
@@ -551,17 +570,21 @@ var ChatView = GObject.registerClass({
         if (source instanceof Tp.Message) {
             let [text] = source.to_text();
             let [id, valid] = source.get_pending_message_id();
-            return { nick: source.sender.alias,
-                     text: text,
-                     timestamp: source.get_sent_timestamp() ||
-                                source.get_received_timestamp(),
-                     messageType: source.get_message_type(),
-                     pendingId: valid ? id : undefined };
+            return {
+                nick: source.sender.alias,
+                text: text,
+                timestamp: source.get_sent_timestamp() ||
+                           source.get_received_timestamp(),
+                messageType: source.get_message_type(),
+                pendingId: valid ? id : undefined
+            };
         } else if (source instanceof Tpl.Event) {
-            return { nick: source.sender.alias,
-                     text: source.message,
-                     timestamp: source.timestamp,
-                     messageType: source.get_message_type() };
+            return {
+                nick: source.sender.alias,
+                text: source.message,
+                timestamp: source.timestamp,
+                messageType: source.get_message_type()
+            };
         }
 
         throw new Error(`Cannot create message from source ${source}`);
@@ -727,7 +750,7 @@ var ChatView = GObject.registerClass({
 
         this._fetchingBacklog = true;
         this._showLoadingIndicator();
-        this._backlogTimeoutId = Mainloop.timeout_add(500, () => {
+        this._backlogTimeoutId = GLib.timeout_add(GLib.PRIORITY_DEFAULT, 500, () => {
             this._logWalker.get_events_async(NUM_LOG_EVENTS,
                                              this._onLogEventsReady.bind(this));
             this._backlogTimeoutId = 0;
@@ -740,7 +763,7 @@ var ChatView = GObject.registerClass({
         if (this._valueChangedId)
             return;
 
-        this._valueChangedId = Mainloop.timeout_add(SCROLL_TIMEOUT, () => {
+        this._valueChangedId = GLib.timeout_add(GLib.PRIORITY_DEFAULT, SCROLL_TIMEOUT, () => {
             this._checkMessages();
             this._valueChangedId = 0;
             return GLib.SOURCE_REMOVE;
@@ -766,13 +789,13 @@ var ChatView = GObject.registerClass({
     _showUrlContextMenu(url) {
         let menu = new Gtk.Menu();
 
-        let item = new Gtk.MenuItem({ label: _("Open Link") });
+        let item = new Gtk.MenuItem({ label: _('Open Link') });
         item.connect('activate', () => {
             Utils.openURL(url, Gtk.get_current_event_time());
         });
         menu.append(item);
 
-        item = new Gtk.MenuItem({ label: _("Copy Link Address") });
+        item = new Gtk.MenuItem({ label: _('Copy Link Address') });
         item.connect('activate', () => {
             let clipboard = Gtk.Clipboard.get_default(item.get_display());
             clipboard.set_text(url, -1);
@@ -795,7 +818,7 @@ var ChatView = GObject.registerClass({
         else
             hoveredButtonTags = [];
 
-        hoveredButtonTags.forEach(t => { t.hover = true; });
+        hoveredButtonTags.forEach(t => t.hover = true);
         this._hoveredButtonTags.forEach(t => {
             t.hover = hoveredButtonTags.includes(t);
         });
@@ -814,8 +837,10 @@ var ChatView = GObject.registerClass({
     }
 
     _showLoadingIndicator() {
-        let indicator = new Gtk.Image({ icon_name: 'content-loading-symbolic',
-                                        visible: true });
+        let indicator = new Gtk.Image({
+            icon_name: 'content-loading-symbolic',
+            visible: true
+        });
         indicator.get_style_context().add_class('dim-label');
 
         let buffer = this._view.buffer;
@@ -914,8 +939,9 @@ var ChatView = GObject.registerClass({
 
         this._channel = this._room.channel;
 
-        let nick = this._channel ? this._channel.connection.self_contact.alias
-                                 : this._room.account.nickname;
+        let nick = this._channel ?
+            this._channel.connection.self_contact.alias :
+            this._room.account.nickname;
         this._updateMaxNickChars(nick.length);
 
         if (!this._channel)
@@ -923,14 +949,16 @@ var ChatView = GObject.registerClass({
 
         this._joinTime = GLib.DateTime.new_now_utc().to_unix();
 
-        let channelSignals = [
-            { name: 'message-received',
-              handler: this._onMessageReceived.bind(this) },
-            { name: 'message-sent',
-              handler: this._onMessageSent.bind(this) },
-            { name: 'pending-message-removed',
-              handler: this._pendingMessageRemoved.bind(this) }
-        ];
+        let channelSignals = [{
+            name: 'message-received',
+            handler: this._onMessageReceived.bind(this)
+        }, {
+            name: 'message-sent',
+            handler: this._onMessageSent.bind(this)
+        }, {
+            name: 'pending-message-removed',
+            handler: this._pendingMessageRemoved.bind(this)
+        }];
         channelSignals.forEach(signal => {
             this._channelSignals.push(this._channel.connect(signal.name, signal.handler));
         });
@@ -940,40 +968,40 @@ var ChatView = GObject.registerClass({
     }
 
     _onMemberRenamed(room, oldMember, newMember) {
-        let text = _("%s is now known as %s").format(oldMember.alias, newMember.alias);
+        let text = _('%s is now known as %s').format(oldMember.alias, newMember.alias);
         this._insertStatus(text, oldMember.alias, 'renamed');
     }
 
     _onMemberDisconnected(room, member, message) {
-        let text = _("%s has disconnected").format(member.alias);
+        let text = _('%s has disconnected').format(member.alias);
         if (message)
             text += ` (${message})`;
         this._insertStatus(text, member.alias, 'left');
     }
 
     _onMemberKicked(room, member, actor) {
-        let message =
-            actor ? _("%s has been kicked by %s").format(member.alias,
-                                                         actor.alias)
-                  : _("%s has been kicked").format(member.alias);
-        this._insertStatus(message, member.alias, 'left');
+        let [kicked, kicker] = [member.alias, actor ? actor.alias : null];
+        let msg = kicker ?
+            _('%s has been kicked by %s').format(kicked, kicker) :
+            _('%s has been kicked').format(kicked);
+        this._insertStatus(msg, kicked, 'left');
     }
 
     _onMemberBanned(room, member, actor) {
-        let message =
-            actor ? _("%s has been banned by %s").format(member.alias,
-                                                         actor.alias)
-                  : _("%s has been banned").format(member.alias);
-        this._insertStatus(message, member.alias, 'left');
+        let [banned, banner] = [member.alias, actor ? actor.alias : null];
+        let msg = banner ?
+            _('%s has been banned by %s').format(banned, banner) :
+            _('%s has been banned').format(banned);
+        this._insertStatus(msg, banned, 'left');
     }
 
     _onMemberJoined(room, member) {
-        let text = _("%s joined").format(member.alias);
+        let text = _('%s joined').format(member.alias);
         this._insertStatus(text, member.alias, 'joined');
     }
 
     _onMemberLeft(room, member, message) {
-        let text = _("%s left").format(member.alias);
+        let text = _('%s left').format(member.alias);
 
         if (message)
             text += ` (${message})`;
@@ -1066,11 +1094,11 @@ var ChatView = GObject.registerClass({
 
         let stats = [];
         if (this._statusCount.joined > 0)
-            stats.push(ngettext("%d user joined",
-                                "%d users joined", this._statusCount.joined).format(this._statusCount.joined));
+            stats.push(ngettext('%d user joined',
+                                '%d users joined', this._statusCount.joined).format(this._statusCount.joined));
         if (this._statusCount.left > 0)
-            stats.push(ngettext("%d user left",
-                                "%d users left", this._statusCount.left).format(this._statusCount.left));
+            stats.push(ngettext('%d user left',
+                                '%d users left', this._statusCount.left).format(this._statusCount.left));
         // TODO: How do we update the arrow direction when text direction change?
         let iter = buffer.get_iter_at_mark(headerMark);
         let tags = [this._lookupTag('status'), headerTag];
@@ -1136,56 +1164,56 @@ var ChatView = GObject.registerClass({
         if (clockFormat == '24h' || !hasAmPm) {
             if (daysAgo < 1) { // today
                 /* Translators: Time in 24h format */
-                format = _("%H\u2236%M");
+                format = _('%H\u2236%M');
             } else if (daysAgo < 2) { // yesterday
                 /* Translators: this is the word "Yesterday" followed by a
                  time string in 24h format. i.e. "Yesterday, 14:30" */
                 // xgettext:no-c-format
-                format = _("Yesterday, %H\u2236%M");
+                format = _('Yesterday, %H\u2236%M');
             } else if (daysAgo < 7) { // this week
                 /* Translators: this is the week day name followed by a time
                  string in 24h format. i.e. "Monday, 14:30" */
                 // xgettext:no-c-format
-                format = _("%A, %H\u2236%M");
+                format = _('%A, %H\u2236%M');
             } else if (date.get_year() == now.get_year()) { // this year
                 /* Translators: this is the month name and day number
                  followed by a time string in 24h format.
                  i.e. "May 25, 14:30" */
                 // xgettext:no-c-format
-                format = _("%B %d, %H\u2236%M");
+                format = _('%B %d, %H\u2236%M');
             } else { // before this year
                 /* Translators: this is the month name, day number, year
                  number followed by a time string in 24h format.
                  i.e. "May 25 2012, 14:30" */
                 // xgettext:no-c-format
-                format = _("%B %d %Y, %H\u2236%M");
+                format = _('%B %d %Y, %H\u2236%M');
             }
         } else {
             if (daysAgo < 1) { // today
                 /* Translators: Time in 12h format */
-                format = _("%l\u2236%M %p");
+                format = _('%l\u2236%M %p');
             } else if (daysAgo < 2) { // yesterday
                 /* Translators: this is the word "Yesterday" followed by a
                  time string in 12h format. i.e. "Yesterday, 2:30 pm" */
                 // xgettext:no-c-format
-                format = _("Yesterday, %l\u2236%M %p");
+                format = _('Yesterday, %l\u2236%M %p');
             } else if (daysAgo < 7) { // this week
                 /* Translators: this is the week day name followed by a time
                  string in 12h format. i.e. "Monday, 2:30 pm" */
                 // xgettext:no-c-format
-                format = _("%A, %l\u2236%M %p");
+                format = _('%A, %l\u2236%M %p');
             } else if (date.get_year() == now.get_year()) { // this year
                 /* Translators: this is the month name and day number
                  followed by a time string in 12h format.
                  i.e. "May 25, 2:30 pm" */
                 // xgettext:no-c-format
-                format = _("%B %d, %l\u2236%M %p");
+                format = _('%B %d, %l\u2236%M %p');
             } else { // before this year
                 /* Translators: this is the month name, day number, year
                  number followed by a time string in 12h format.
                  i.e. "May 25 2012, 2:30 pm"*/
                 // xgettext:no-c-format
-                format = _("%B %d %Y, %l\u2236%M %p");
+                format = _('%B %d %Y, %l\u2236%M %p');
             }
         }
 
@@ -1251,8 +1279,10 @@ var ChatView = GObject.registerClass({
                 }
                 tags.push(nickTag);
 
-                let hoverTag = new HoverFilterTag({ filtered_tag: nickTag,
-                                                    hover_opacity: 0.8 });
+                let hoverTag = new HoverFilterTag({
+                    filtered_tag: nickTag,
+                    hover_opacity: 0.8
+                });
                 buffer.get_tag_table().add(hoverTag);
 
                 tags.push(hoverTag);
@@ -1357,9 +1387,11 @@ var ChatView = GObject.registerClass({
         let actualNickName = view.get_buffer().get_slice(start, end, false);
 
         if (!tag._popover)
-            tag._popover = new UserPopover({ relative_to: this._view,
-                                             userTracker: this._userTracker,
-                                             room: this._room });
+            tag._popover = new UserPopover({
+                relative_to: this._view,
+                userTracker: this._userTracker,
+                room: this._room
+            });
 
         tag._popover.nickname = actualNickName;
 
