@@ -12,11 +12,13 @@ const SetupPage = {
 
 var InitialSetupWindow = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/initial-setup-window.ui',
-    InternalChildren: ['contentStack',
-                       'connectionsList',
-                       'nextButton',
-                       'prevButton',
-                       'serverRoomList'],
+    InternalChildren: [
+        'contentStack',
+        'connectionsList',
+        'nextButton',
+        'prevButton',
+        'serverRoomList'
+    ]
 }, class InitialSetupWindow extends Gtk.Window {
     _init(params) {
 
@@ -30,7 +32,7 @@ var InitialSetupWindow = GObject.registerClass({
             this._serverRoomList.setAccount(account);
         });
 
-        this.connect('destroy', () => { this._unsetAccount(); });
+        this.connect('destroy', () => this._unsetAccount());
 
         this._serverRoomList.connect('notify::can-join',
                                      this._updateNextSensitivity.bind(this));
@@ -63,8 +65,8 @@ var InitialSetupWindow = GObject.registerClass({
 
     _onNetworkAvailableChanged() {
         if (this._networkMonitor.network_available)
-            this._setPage(this._currentAccount ? SetupPage.ROOM
-                                               : SetupPage.CONNECTION);
+            this._setPage(this._currentAccount ?
+                SetupPage.ROOM : SetupPage.CONNECTION);
         else
             this._setPage(SetupPage.OFFLINE);
     }
@@ -79,8 +81,8 @@ var InitialSetupWindow = GObject.registerClass({
 
         let isLastPage = page == SetupPage.ROOM;
 
-        this._prevButton.label = isLastPage ? _("_Back") : _("_Cancel");
-        this._nextButton.label = isLastPage ? _("_Done") : _("_Next");
+        this._prevButton.label = isLastPage ? _('_Back') : _('_Cancel');
+        this._nextButton.label = isLastPage ? _('_Done') : _('_Next');
 
         let context = this._nextButton.get_style_context();
         if (isLastPage)
