@@ -12,18 +12,20 @@ const DialogPage = {
 
 var JoinDialog = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/join-room-dialog.ui',
-    InternalChildren: ['cancelButton',
-                       'joinButton',
-                       'mainStack',
-                       'connectionCombo',
-                       'connectionButton',
-                       'connectionStack',
-                       'filterEntry',
-                       'connectionsList',
-                       'serverRoomList',
-                       'details',
-                       'addButton',
-                       'customToggle'],
+    InternalChildren: [
+        'cancelButton',
+        'joinButton',
+        'mainStack',
+        'connectionCombo',
+        'connectionButton',
+        'connectionStack',
+        'filterEntry',
+        'connectionsList',
+        'serverRoomList',
+        'details',
+        'addButton',
+        'customToggle'
+    ]
 }, class JoinDialog extends Gtk.Dialog {
     _init(params) {
         params['use-header-bar'] = 1;
@@ -31,9 +33,11 @@ var JoinDialog = GObject.registerClass({
 
         // TODO: Is there really no way to do this in the template?
         let icon = new Gtk.Image({ icon_name: 'go-previous-symbolic' });
-        this._backButton = new Gtk.Button({ image: icon,
-                                            valign: Gtk.Align.CENTER,
-                                            focus_on_click: false });
+        this._backButton = new Gtk.Button({
+            image: icon,
+            valign: Gtk.Align.CENTER,
+            focus_on_click: false
+        });
         this.get_header_bar().pack_start(this._backButton);
 
         let accelGroup = new Gtk.AccelGroup();
@@ -120,8 +124,8 @@ var JoinDialog = GObject.registerClass({
 
         this._customToggle.connect('notify::active', () => {
             let isCustom = this._customToggle.active;
-            this._connectionStack.visible_child_name = isCustom ? 'custom'
-                                                                : 'predefined';
+            let childName = isCustom ? 'custom' : 'predefined';
+            this._connectionStack.visible_child_name = childName;
             if (isCustom) {
                 this._addButton.grab_default();
                 this._details.reset();
@@ -169,10 +173,11 @@ var JoinDialog = GObject.registerClass({
 
             let app = Gio.Application.get_default();
             let action = app.lookup_action('join-room');
-            action.activate(GLib.Variant.new('(ssu)',
-                                             [account.get_object_path(),
-                                              room,
-                                              Utils.getTpEventTime()]));
+            action.activate(GLib.Variant.new('(ssu)', [
+                account.get_object_path(),
+                room,
+                Utils.getTpEventTime()
+            ]));
         });
     }
 
@@ -187,8 +192,8 @@ var JoinDialog = GObject.registerClass({
             this._connectionCombo.append(names[i], names[i]);
         this._connectionCombo.sensitive = names.length > 1;
 
-        let activeRoom = this.transient_for ? this.transient_for.active_room
-                                            : null;
+        let activeRoom = this.transient_for ?
+            this.transient_for.active_room : null;
         let activeIndex = 0;
         if (activeRoom)
             activeIndex = Math.max(names.indexOf(activeRoom.account.display_name), 0);
@@ -203,8 +208,8 @@ var JoinDialog = GObject.registerClass({
                         this._serverRoomList.can_join;
 
         this._joinButton.sensitive = sensitive;
-        this.set_default_response(sensitive ? Gtk.ResponseType.OK
-                                            : Gtk.ResponseType.NONE);
+        this.set_default_response(sensitive ?
+            Gtk.ResponseType.OK : Gtk.ResponseType.NONE);
     }
 
     get _page() {
@@ -226,8 +231,7 @@ var JoinDialog = GObject.registerClass({
         this._joinButton.visible = isMain;
         this._cancelButton.visible = isMain || isAccountsEmpty;
         this._backButton.visible = !(isMain || isAccountsEmpty);
-        this.title = isMain ? _("Join Chat Room")
-                            : _("Add Network");
+        this.title = isMain ? _('Join Chat Room') : _('Add Network');
         this._mainStack.visible_child_name = isMain ? 'main' : 'connection';
         this._updateCanJoin();
     }
