@@ -4,14 +4,16 @@ pkg.initFormat();
 pkg.initGettext();
 window.ngettext = imports.gettext.ngettext;
 
-pkg.require({ 'GdkPixbuf': '2.0',
-              'GObject': '2.0',
-              'Pango': '1.0',
-              'PangoCairo': '1.0',
-              'Secret': '1',
-              'Soup': '2.4',
-              'TelepathyGLib': '0.12',
-              'TelepathyLogger': '0.2' });
+pkg.require({
+    'GdkPixbuf': '2.0',
+    'GObject': '2.0',
+    'Pango': '1.0',
+    'PangoCairo': '1.0',
+    'Secret': '1',
+    'Soup': '2.4',
+    'TelepathyGLib': '0.12',
+    'TelepathyLogger': '0.2'
+});
 pkg.requireSymbol('Gio', '2.0', 'Application.send_notification');
 pkg.requireSymbol('GLib', '2.0', 'log_variant');
 pkg.requireSymbol('Gspell', '1', 'Entry');
