@@ -1,7 +1,6 @@
 /* exported MainWindow FixedSizeFrame RoomList RoomStack UserList */
 
 const { Gdk, Gio, GLib, GObject, Gtk, Polari, TelepathyGLib: Tp } = imports.gi;
-const Mainloop = imports.mainloop;
 
 const { AccountsMonitor } = imports.accountsMonitor;
 const { JoinDialog } = imports.joinDialog;
@@ -24,7 +23,7 @@ var FixedSizeFrame = GObject.registerClass({
                                      'width',
                                      GObject.ParamFlags.READWRITE,
                                      -1, GLib.MAXINT32, -1)
-    },
+    }
 }, class FixedSizeFrame extends Gtk.Frame {
     _init(params) {
         this._height = -1;
@@ -80,14 +79,16 @@ var FixedSizeFrame = GObject.registerClass({
 
 var MainWindow = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/main-window.ui',
-    InternalChildren: ['titlebarRight',
-                       'titlebarLeft',
-                       'joinButton',
-                       'showUserListButton',
-                       'userListPopover',
-                       'roomListRevealer',
-                       'overlay',
-                       'roomStack'],
+    InternalChildren: [
+        'titlebarRight',
+        'titlebarLeft',
+        'joinButton',
+        'showUserListButton',
+        'userListPopover',
+        'roomListRevealer',
+        'overlay',
+        'roomStack',
+    ],
     Properties: {
         subtitle: GObject.ParamSpec.string('subtitle',
                                            'subtitle',
@@ -105,7 +106,9 @@ var MainWindow = GObject.registerClass({
                                                 GObject.ParamFlags.READWRITE,
                                                 Polari.Room.$gtype)
     },
-    Signals: { 'active-room-state-changed': {} },
+    Signals: {
+        'active-room-state-changed': {}
+    }
 }, class MainWindow extends Gtk.ApplicationWindow {
     _init(params) {
         this._subtitle = '';
@@ -147,7 +150,7 @@ var MainWindow = GObject.registerClass({
         // Make sure user-list button is at least as wide as icon buttons
         this._joinButton.connect('size-allocate', (w, rect) => {
             let width = rect.width;
-            Mainloop.idle_add(() => {
+            GLib.idle_add(GLib.PRIORITY_DEFAULT_IDLE, () => {
                 this._showUserListButton.width_request = width;
                 return GLib.SOURCE_REMOVE;
             });
@@ -355,8 +358,8 @@ var MainWindow = GObject.registerClass({
             this._room.channel.has_interface(Tp.IFACE_CHANNEL_INTERFACE_GROUP))
             numMembers = this._room.channel.group_dup_members_contacts().length;
 
-        let accessibleName = ngettext("%d user",
-                                      "%d users", numMembers).format(numMembers);
+        let accessibleName = ngettext('%d user',
+                                      '%d users', numMembers).format(numMembers);
         this._showUserListButton.get_accessible().set_name(accessibleName);
         this._showUserListButton.label = `${numMembers}`;
     }
