@@ -19,15 +19,17 @@ var RoomManager = class {
         this._accountsMonitor = AccountsMonitor.getDefault();
 
         this._app = Gio.Application.get_default();
-        let actions = [
-            { name: 'join-room',
-              handler: this._onJoinActivated.bind(this) },
-            { name: 'message-user',
-              handler: this._onQueryActivated.bind(this) },
-            { name: 'leave-room',
-              after: true,
-              handler: this._onLeaveActivated.bind(this) }
-        ];
+        let actions = [{
+            name: 'join-room',
+            handler: this._onJoinActivated.bind(this)
+        }, {
+            name: 'message-user',
+            handler: this._onQueryActivated.bind(this)
+        }, {
+            name: 'leave-room',
+            after: true,
+            handler: this._onLeaveActivated.bind(this)
+        }];
         actions.forEach(a => {
             if (a.after)
                 this._app.lookup_action(a.name).connect_after('activate', a.handler);
@@ -45,7 +47,7 @@ var RoomManager = class {
             this._removeRooms(account.object_path);
             this._removeSavedChannelsForAccount(account.object_path);
         });
-        this._accountsMonitor.prepare(() => { this._restoreRooms(); });
+        this._accountsMonitor.prepare(() => this._restoreRooms());
     }
 
     lookupRoom(id) {
@@ -170,9 +172,11 @@ var RoomManager = class {
         let id = Polari.create_room_id(account, channelName, type);
         let room = this._rooms.get(id);
         if (!room) {
-            room = new Polari.Room({ account: account,
-                                     channel_name: channelName,
-                                     type: type });
+            room = new Polari.Room({
+                account: account,
+                channel_name: channelName,
+                type: type
+            });
             this._rooms.set(room.id, room);
             this.emit('room-added', room);
         }
@@ -187,8 +191,8 @@ var RoomManager = class {
     ensureRoomForChannel(channel, time) {
         let accountPath = channel.connection.get_account().object_path;
         let targetContact = channel.target_contact;
-        let channelName = targetContact ? targetContact.alias
-                                        : channel.identifier;
+        let channelName = targetContact ?
+            targetContact.alias : channel.identifier;
         let [, handleType] = channel.get_handle();
         let room = this._ensureRoom(accountPath, channelName, handleType, time);
         room.channel = channel;
