@@ -1,7 +1,6 @@
 /* exported ServerRoomManager ServerRoomList */
 
 const { Gdk, GLib, GObject, Gtk, TelepathyGLib: Tp } = imports.gi;
-const Mainloop = imports.mainloop;
 const Signals = imports.signals;
 
 const { AccountsMonitor } = imports.accountsMonitor;
@@ -96,10 +95,9 @@ Signals.addSignalMethods(ServerRoomManager.prototype);
 
 
 const RoomListColumn = {
-    CHECKED:   0,
-    NAME:      1,
-    COUNT:     2,
-
+    CHECKED: 0,
+    NAME: 1,
+    COUNT: 2,
     SENSITIVE: 3,
 };
 
@@ -109,16 +107,20 @@ function _strBaseEqual(str1, str2) {
 
 var ServerRoomList = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/server-room-list.ui',
-    InternalChildren: ['filterEntry',
-                       'list',
-                       'spinner',
-                       'store',
-                       'toggleRenderer'],
-    Properties: { 'can-join': GObject.ParamSpec.boolean('can-join',
-                                                        'can-join',
-                                                        'can-join',
-                                                        GObject.ParamFlags.READABLE,
-                                                        false) },
+    InternalChildren: [
+        'filterEntry',
+        'list',
+        'spinner',
+        'store',
+        'toggleRenderer'
+    ],
+    Properties: {
+        'can-join': GObject.ParamSpec.boolean('can-join',
+                                              'can-join',
+                                              'can-join',
+                                              GObject.ParamFlags.READABLE,
+                                              false)
+    }
 }, class ServerRoomList extends Gtk.Box {
     _init(params) {
         this._account = null;
@@ -290,7 +292,7 @@ var ServerRoomList = GObject.registerClass({
         this._clearList();
 
         if (this._idleId)
-            Mainloop.source_remove(this._idleId);
+            GLib.source_remove(this._idleId);
 
         if (!account)
             return;
@@ -309,7 +311,7 @@ var ServerRoomList = GObject.registerClass({
 
         let roomManager = RoomManager.getDefault();
 
-        this._idleId = Mainloop.idle_add(() => {
+        this._idleId = GLib.idle_add(GLib.PRIORITY_DEFAULT_IDLE, () => {
             let customName = this._store.get_value(this._customRoomItem,
                                                    RoomListColumn.NAME);
             let store = this._store;
@@ -336,8 +338,8 @@ var ServerRoomList = GObject.registerClass({
                                                      [checked, name, count, sensitive]);
                 store.move_before(iter, this._customRoomItem);
 
-                let maxTime = this._filterTerms.length > 0 ? MS_PER_FILTER_IDLE
-                                                           : MS_PER_IDLE;
+                let maxTime = this._filterTerms.length > 0 ?
+                    MS_PER_FILTER_IDLE : MS_PER_IDLE;
                 // Limit time spent in idle to leave room for drawing etc.
                 if (GLib.get_monotonic_time() - startTime > 1000 * maxTime)
                     return GLib.SOURCE_CONTINUE;
