@@ -41,10 +41,12 @@ var TabCompletion = class {
             let row = new Gtk.ListBoxRow();
             row._text = `/${commands[i]}`;
             row._casefoldedText = row._text.toLowerCase();
-            row.add(new Gtk.Label({ label: row._text,
-                                    halign: Gtk.Align.START,
-                                    margin_start: 6,
-                                    margin_end: 6 }));
+            row.add(new Gtk.Label({
+                label: row._text,
+                halign: Gtk.Align.START,
+                margin_start: 6,
+                margin_end: 6
+            }));
             this._list.add(row);
         }
     }
@@ -94,10 +96,12 @@ var TabCompletion = class {
                 row = new Gtk.ListBoxRow();
                 row._text = nick;
                 row._casefoldedText = row._text.toLowerCase();
-                row.add(new Gtk.Label({ label: row._text,
-                                        halign: Gtk.Align.START,
-                                        margin_start: 6,
-                                        margin_end: 6 }));
+                row.add(new Gtk.Label({
+                    label: row._text,
+                    halign: Gtk.Align.START,
+                    margin_start: 6,
+                    margin_end: 6
+                }));
                 widgetMap.set(nick, row);
             }
         }
@@ -129,17 +133,17 @@ var TabCompletion = class {
         }
 
         switch (keyval) {
-            case Gdk.KEY_Tab:
-            case Gdk.KEY_Down:
-                this._moveSelection(Gtk.MovementStep.DISPLAY_LINES, 1);
-                return Gdk.EVENT_STOP;
-            case Gdk.KEY_ISO_Left_Tab:
-            case Gdk.KEY_Up:
-                this._moveSelection(Gtk.MovementStep.DISPLAY_LINES, -1);
-                return Gdk.EVENT_STOP;
-            case Gdk.KEY_Escape:
-                this._cancel();
-                return Gdk.EVENT_STOP;
+        case Gdk.KEY_Tab:
+        case Gdk.KEY_Down:
+            this._moveSelection(Gtk.MovementStep.DISPLAY_LINES, 1);
+            return Gdk.EVENT_STOP;
+        case Gdk.KEY_ISO_Left_Tab:
+        case Gdk.KEY_Up:
+            this._moveSelection(Gtk.MovementStep.DISPLAY_LINES, -1);
+            return Gdk.EVENT_STOP;
+        case Gdk.KEY_Escape:
+            this._cancel();
+            return Gdk.EVENT_STOP;
         }
 
         if (Gdk.keyval_to_unicode(keyval) != 0) {
