@@ -3,7 +3,6 @@
 const {
     Gio, GLib, GObject, Gtk, Pango, Polari, TelepathyGLib: Tp
 } = imports.gi;
-const Mainloop = imports.mainloop;
 
 const READWRITE = GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE;
 
@@ -17,7 +16,7 @@ class UserListPopover extends Gtk.Popover {
 
         this._createWidget();
 
-        this.connect('closed', () => { this._entry.text = ''; });
+        this.connect('closed', () => this._entry.text = '');
         this.connect('map', () => {
             this._revealer.transition_duration = 0;
             this._ensureUserList();
@@ -36,8 +35,10 @@ class UserListPopover extends Gtk.Popover {
     }
 
     _createWidget() {
-        this._box = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL,
-                                  spacing: 6 });
+        this._box = new Gtk.Box({
+            orientation: Gtk.Orientation.VERTICAL,
+            spacing: 6
+        });
         this.add(this._box);
 
         this._revealer = new Gtk.Revealer();
@@ -46,7 +47,9 @@ class UserListPopover extends Gtk.Popover {
         this._userListBin = new Gtk.Frame({ shadow_type: Gtk.ShadowType.NONE });
         this._box.add(this._userListBin);
 
-        this._entry = new Gtk.SearchEntry({ primary_icon_name: 'avatar-default-symbolic' });
+        this._entry = new Gtk.SearchEntry({
+            primary_icon_name: 'avatar-default-symbolic'
+        });
         this._entry.connect('search-changed', this._updateFilter.bind(this));
         this._revealer.add(this._entry);
 
@@ -95,23 +98,27 @@ class UserListPopover extends Gtk.Popover {
 
 var UserDetails = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/user-details.ui',
-    InternalChildren: ['spinnerBox',
-                       'spinner',
-                       'detailsGrid',
-                       'fullnameLabel',
-                       'lastLabel',
-                       'notificationLabel',
-                       'messageButton'],
-    Properties: { 'expanded': GObject.ParamSpec.boolean('expanded',
-                                                        'expanded',
-                                                        'expanded',
-                                                        READWRITE,
-                                                        false),
-                  'notifications-enabled': GObject.ParamSpec.boolean('notifications-enabled',
-                                                                     'notifications-enabled',
-                                                                     'notifications-enabled',
-                                                                     READWRITE,
-                                                                     false) },
+    InternalChildren: [
+        'spinnerBox',
+        'spinner',
+        'detailsGrid',
+        'fullnameLabel',
+        'lastLabel',
+        'notificationLabel',
+        'messageButton'
+    ],
+    Properties: {
+        'expanded': GObject.ParamSpec.boolean('expanded',
+                                              'expanded',
+                                              'expanded',
+                                              READWRITE,
+                                              false),
+        'notifications-enabled': GObject.ParamSpec.boolean('notifications-enabled',
+                                                           'notifications-enabled',
+                                                           'notifications-enabled',
+                                                           READWRITE,
+                                                           false)
+    }
 }, class UserDetails extends Gtk.Frame {
     _init(params = {}) {
         let user = params.user;
@@ -227,32 +234,32 @@ var UserDetails = GObject.registerClass({
 
     _formatLast(seconds) {
         if (seconds < 60)
-            return ngettext("%d second ago",
-                            "%d seconds ago", seconds).format(seconds);
+            return ngettext('%d second ago',
+                            '%d seconds ago', seconds).format(seconds);
 
         let minutes = seconds / 60;
         if (minutes < 60)
-            return ngettext("%d minute ago",
-                            "%d minutes ago", minutes).format(minutes);
+            return ngettext('%d minute ago',
+                            '%d minutes ago', minutes).format(minutes);
 
         let hours = minutes / 60;
         if (hours < 24)
-            return ngettext("%d hour ago",
-                            "%d hours ago", hours).format(hours);
+            return ngettext('%d hour ago',
+                            '%d hours ago', hours).format(hours);
 
         let days = hours / 24;
         if (days < 7)
-            return ngettext("%d day ago",
-                            "%d days ago", days).format(days);
+            return ngettext('%d day ago',
+                            '%d days ago', days).format(days);
 
         let weeks = days / 7;
         if (days < 30)
-            return ngettext("%d week ago",
-                            "%d weeks ago", weeks).format(weeks);
+            return ngettext('%d week ago',
+                            '%d weeks ago', weeks).format(weeks);
 
         let months = days / 30;
-        return ngettext("%d month ago",
-                        "%d months ago", months).format(months);
+        return ngettext('%d month ago',
+                        '%d months ago', months).format(months);
     }
 
     _onContactInfoReady() {
@@ -294,11 +301,12 @@ var UserDetails = GObject.registerClass({
         let app = Gio.Application.get_default();
         let action = app.lookup_action('message-user');
         let time = Gtk.get_current_event().get_time();
-        action.activate(GLib.Variant.new('(sssu)',
-                                         [account.get_object_path(),
-                                          this._user.alias,
-                                          '',
-                                          time]));
+        action.activate(GLib.Variant.new('(sssu)', [
+            account.get_object_path(),
+            this._user.alias,
+            '',
+            time
+        ]));
     }
 
     _updateButtonVisibility() {
@@ -320,10 +328,12 @@ var UserDetails = GObject.registerClass({
 
 var UserPopover = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/user-popover.ui',
-    InternalChildren: ['nickLabel',
-                       'statusLabel',
-                       'notifyButton',
-                       'userDetails'],
+    InternalChildren: [
+        'nickLabel',
+        'statusLabel',
+        'notifyButton',
+        'userDetails'
+    ]
 }, class UserPopover extends Gtk.Popover {
     _init(params) {
         this._room = params.room;
@@ -409,11 +419,11 @@ var UserPopover = GObject.registerClass({
 
         let label;
         if (status != roomStatus)
-            label = _("Available in another room.");
+            label = _('Available in another room.');
         else if (status == Tp.ConnectionPresenceType.AVAILABLE)
-            label = _("Online");
+            label = _('Online');
         else
-            label = _("Offline");
+            label = _('Offline');
         this._statusLabel.label = label;
 
         this._nickLabel.sensitive = (status == Tp.ConnectionPresenceType.AVAILABLE);
@@ -461,19 +471,25 @@ class UserListRow extends Gtk.ListBoxRow {
         let vbox = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL });
         this.add(vbox);
 
-        let hbox = new Gtk.Box({ margin_end: 12,
-                                 margin_start: 4,
-                                 margin_top: 4,
-                                 margin_bottom: 4,
-                                 spacing: 4 });
-        this._arrow = new Gtk.Arrow({ arrow_type: Gtk.ArrowType.RIGHT,
-                                      no_show_all: true });
-        this._label = new Gtk.Label({ label: this._user.alias,
-                                      halign: Gtk.Align.START,
-                                      hexpand: true,
-                                      use_markup: true,
-                                      ellipsize: Pango.EllipsizeMode.END,
-                                      max_width_chars: MAX_USERS_WIDTH_CHARS });
+        let hbox = new Gtk.Box({
+            margin_end: 12,
+            margin_start: 4,
+            margin_top: 4,
+            margin_bottom: 4,
+            spacing: 4
+        });
+        this._arrow = new Gtk.Arrow({
+            arrow_type: Gtk.ArrowType.RIGHT,
+            no_show_all: true
+        });
+        this._label = new Gtk.Label({
+            label: this._user.alias,
+            halign: Gtk.Align.START,
+            hexpand: true,
+            use_markup: true,
+            ellipsize: Pango.EllipsizeMode.END,
+            max_width_chars: MAX_USERS_WIDTH_CHARS
+        });
         hbox.add(this._label);
         hbox.add(this._arrow);
         vbox.add(hbox);
@@ -541,23 +557,31 @@ class UserListRow extends Gtk.ListBoxRow {
 var UserList = GObject.registerClass(
 class UserList extends Gtk.ScrolledWindow {
     _init(room) {
-        super._init({ hexpand: true,
-                      shadow_type: Gtk.ShadowType.ETCHED_IN,
-                      hscrollbar_policy: Gtk.PolicyType.NEVER,
-                      propagate_natural_width: true });
+        super._init({
+            hexpand: true,
+            shadow_type: Gtk.ShadowType.ETCHED_IN,
+            hscrollbar_policy: Gtk.PolicyType.NEVER,
+            propagate_natural_width: true
+        });
 
         this._list = new Gtk.ListBox({ vexpand: true });
         this.add(this._list);
 
-        let placeholder = new Gtk.Box({ halign: Gtk.Align.CENTER,
-                                        valign: Gtk.Align.CENTER,
-                                        orientation: Gtk.Orientation.VERTICAL,
-                                        visible: true });
-        placeholder.add(new Gtk.Image({ icon_name: 'edit-find-symbolic',
-                                        pixel_size: 64,
-                                        visible: true }));
-        placeholder.add(new Gtk.Label({ label: _("No results"),
-                                        visible: true }));
+        let placeholder = new Gtk.Box({
+            halign: Gtk.Align.CENTER,
+            valign: Gtk.Align.CENTER,
+            orientation: Gtk.Orientation.VERTICAL,
+            visible: true
+        });
+        placeholder.add(new Gtk.Image({
+            icon_name: 'edit-find-symbolic',
+            pixel_size: 64,
+            visible: true
+        }));
+        placeholder.add(new Gtk.Label({
+            label: _('No results'),
+            visible: true
+        }));
 
         placeholder.get_style_context().add_class('dim-label');
 
@@ -579,22 +603,28 @@ class UserList extends Gtk.ScrolledWindow {
         this._rows = new Map();
         this._activeRow = null;
 
-        let roomSignals = [
-            { name: 'member-renamed',
-              handler: this._onMemberRenamed.bind(this) },
-            { name: 'member-disconnected',
-              handler: this._onMemberRemoved.bind(this) },
-            { name: 'member-kicked',
-              handler: this._onMemberRemoved.bind(this) },
-            { name: 'member-banned',
-              handler: this._onMemberRemoved.bind(this) },
-            { name: 'member-left',
-              handler: this._onMemberRemoved.bind(this) },
-            { name: 'member-joined',
-              handler: this._onMemberJoined.bind(this) },
-            { name: 'notify::channel',
-              handler: this._onChannelChanged.bind(this) }
-        ];
+        let roomSignals = [{
+            name: 'member-renamed',
+            handler: this._onMemberRenamed.bind(this)
+        }, {
+            name: 'member-disconnected',
+            handler: this._onMemberRemoved.bind(this)
+        }, {
+            name: 'member-kicked',
+            handler: this._onMemberRemoved.bind(this)
+        }, {
+            name: 'member-banned',
+            handler: this._onMemberRemoved.bind(this)
+        }, {
+            name: 'member-left',
+            handler: this._onMemberRemoved.bind(this)
+        }, {
+            name: 'member-joined',
+            handler: this._onMemberJoined.bind(this)
+        }, {
+            name: 'notify::channel',
+            handler: this._onChannelChanged.bind(this)
+        }];
         this._roomSignals = [];
         roomSignals.forEach(signal => {
             this._roomSignals.push(room.connect(signal.name, signal.handler));
@@ -623,7 +653,7 @@ class UserList extends Gtk.ScrolledWindow {
         if (this._updateHeightId != 0)
             return;
 
-        this._updateHeightId = Mainloop.idle_add(() => {
+        this._updateHeightId = GLib.idle_add(GLib.PRIORITY_DEFAULT_IDLE, () => {
             let topRow = this._list.get_row_at_y(this.vadjustment.value);
             let membersShown = Math.min(this.numRows, MAX_USERS_SHOWN);
             // topRow is unset when all rows are hidden due to filtering,
@@ -657,7 +687,7 @@ class UserList extends Gtk.ScrolledWindow {
     }
 
     _onChannelChanged(room) {
-        this._list.foreach(w => { w.destroy(); });
+        this._list.foreach(w => w.destroy());
         this._rows.clear();
 
         if (!room.channel)
