@@ -96,22 +96,28 @@ const UserTracker = GObject.registerClass({
 
         this._ensureRoomMappingForRoom(room);
 
-        let roomSignals = [
-            { name: 'notify::channel',
-              handler: this._onChannelChanged.bind(this) },
-            { name: 'member-renamed',
-              handler: this._onMemberRenamed.bind(this) },
-            { name: 'member-disconnected',
-              handler: this._onMemberLeft.bind(this) },
-            { name: 'member-kicked',
-              handler: this._onMemberLeft.bind(this) },
-            { name: 'member-banned',
-              handler: this._onMemberLeft.bind(this) },
-            { name: 'member-joined',
-              handler: this._onMemberJoined.bind(this) },
-            { name: 'member-left',
-              handler: this._onMemberLeft.bind(this) }
-        ];
+        let roomSignals = [{
+            name: 'notify::channel',
+            handler: this._onChannelChanged.bind(this)
+        }, {
+            name: 'member-renamed',
+            handler: this._onMemberRenamed.bind(this)
+        }, {
+            name: 'member-disconnected',
+            handler: this._onMemberLeft.bind(this)
+        }, {
+            name: 'member-kicked',
+            handler: this._onMemberLeft.bind(this)
+        }, {
+            name: 'member-banned',
+            handler: this._onMemberLeft.bind(this)
+        }, {
+            name: 'member-joined',
+            handler: this._onMemberJoined.bind(this)
+        }, {
+            name: 'member-left',
+            handler: this._onMemberLeft.bind(this)
+        }];
 
         let signalIds = this._getRoomSignals(room);
         roomSignals.forEach(signal => {
@@ -123,7 +129,7 @@ const UserTracker = GObject.registerClass({
         if (!this._roomData.has(room))
             return;
 
-        this._getRoomSignals(room).forEach(id => { room.disconnect(id); });
+        this._getRoomSignals(room).forEach(id => room.disconnect(id));
         this._clearUsersFromRoom(room);
         this._roomData.delete(room);
     }
@@ -142,21 +148,23 @@ const UserTracker = GObject.registerClass({
 
         /*keep track of initial members in the room, both locally and
         globally*/
-        members.forEach(m => { this._trackMember(m, room); });
+        members.forEach(m => this._trackMember(m, room));
     }
 
     _clearUsersFromRoom(room) {
         let map = this._getRoomContacts(room);
         for (let [, contacts] of map)
-            contacts.slice().forEach((m) => { this._untrackMember(m, room); });
+            contacts.slice().forEach((m) => this._untrackMember(m, room));
     }
 
     _ensureRoomMappingForRoom(room) {
         if (this._roomData.has(room))
             return;
-        this._roomData.set(room, { contactMapping: new Map(),
-                                   handlerMapping: new Map(),
-                                   roomSignals: [] });
+        this._roomData.set(room, {
+            contactMapping: new Map(),
+            handlerMapping: new Map(),
+            roomSignals: []
+        });
     }
 
     _onMemberRenamed(room, oldMember, newMember) {
@@ -255,8 +263,9 @@ const UserTracker = GObject.registerClass({
         let baseNick = Polari.util_get_basenick(nickName);
 
         let contacts = this._baseNickContacts.get(baseNick) || [];
-        return contacts.length == 0 ? Tp.ConnectionPresenceType.OFFLINE
-                                    : Tp.ConnectionPresenceType.AVAILABLE;
+        return contacts.length == 0 ?
+            Tp.ConnectionPresenceType.OFFLINE :
+            Tp.ConnectionPresenceType.AVAILABLE;
     }
 
     getNickRoomStatus(nickName, room) {
@@ -265,8 +274,9 @@ const UserTracker = GObject.registerClass({
         this._ensureRoomMappingForRoom(room);
 
         let contacts = this._getRoomContacts(room).get(baseNick) || [];
-        return contacts.length == 0 ? Tp.ConnectionPresenceType.OFFLINE
-                                    : Tp.ConnectionPresenceType.AVAILABLE;
+        return contacts.length == 0 ?
+            Tp.ConnectionPresenceType.OFFLINE :
+            Tp.ConnectionPresenceType.AVAILABLE;
     }
 
     lookupContact(nickName) {
@@ -302,13 +312,14 @@ const UserTracker = GObject.registerClass({
 
     _notifyNickAvailable (member, room) {
         let notification = new Gio.Notification();
-        notification.set_title(_("User is online"));
-        notification.set_body(_("User %s is now online.").format(member.alias));
+        notification.set_title(_('User is online'));
+        notification.set_body(_('User %s is now online.').format(member.alias));
 
-        let param = GLib.Variant.new('(ssu)',
-                                     [this._account.get_object_path(),
-                                      room.channel_name,
-                                      Utils.getTpEventTime()]);
+        let param = GLib.Variant.new('(ssu)', [
+            this._account.get_object_path(),
+            room.channel_name,
+            Utils.getTpEventTime()
+        ]);
         notification.set_default_action_and_target('app.join-room', param);
 
         this._app.send_notification(this._getNotifyActionNameInternal(member.alias), notification);
@@ -317,8 +328,7 @@ const UserTracker = GObject.registerClass({
     _shouldNotifyNick(nickName) {
         let actionName = this._getNotifyActionNameInternal(nickName);
         let state = this._app.get_action_state(actionName);
-        return state ? state.get_boolean()
-                     : false;
+        return state ? state.get_boolean() : false;
     }
 
     _setNotifyActionEnabled(nickName, enabled) {
@@ -342,9 +352,11 @@ const UserTracker = GObject.registerClass({
             let enabled = status == Tp.ConnectionPresenceType.OFFLINE;
 
             let state = new GLib.Variant('b', false);
-            let action = new Gio.SimpleAction({ name: name,
-                                                enabled: enabled,
-                                                state: state });
+            let action = new Gio.SimpleAction({
+                name: name,
+                enabled: enabled,
+                state: state
+            });
 
             action.connect('notify::enabled', () => {
                 if (!action.enabled)
